# LlamaIndex Workflow

## 🧐 About

This repo is a lightweight fork of LlamaIndex's workflow module, offering powerful event-driven orchestration without the full llama-index-core dependencies. I love the work that LlamaIndex has done with their workflow module, and I wanted a lightweight version that I could use in my own projects without the overhead of the full llama-index-core module.

### Installing

The library is published on PyPI, so you can install it using pip:

```bash
pip install llama-index-workflow
```

## 🎈 Usage

As this is a lightweight version of the LlamaIndex workflow module, the usage is identical to the original module. The main difference is that you don't have to install the full llama-index-core module.

Therefore, the usage is the same as described in the [LlamaIndex documentation](https://docs.llamaindex.ai/en/stable/module_guides/workflow/).

## 👷‍♀️ Contributing

As this is aimed to be a lightweight version of the LlamaIndex workflow module, it is not intended to be extended or modified. If you want to contribute to the workflow module, I recommend checking out the original [llama_index GitHub page](https://github.com/run-llama/llama_index).

Feel free to open an issue or merge request if there are new features in the original LlamaIndex workflow module that you would like to see in this lightweight version.

## ✍️ Authors

- [@maltehedderich](https://github.com/maltehedderich) - Forked from LlamaIndex

The code is 100% based on the work of LlamaIndex, and I am grateful for their work. I am just providing a lightweight version of their workflow module.

## 🎉 Acknowledgements

Huge thanks to all the amazing contributors to the LlamaIndex project. I am grateful for their work and the inspiration they provide to the community.

The following list of authors and maintainers is derived from the pyproject.toml file of the original llama-index-core project:

- Andrei Fajardo <andrei@runllama.ai>
- Haotian Zhang <ht@runllama.ai>
- Jerry Liu <jerry@llamaindex.ai>
- Logan Markewich <logan@llamaindex.ai>
- Simon Suo <simon@llamaindex.ai>
  Sourabh Desai <sourabh@llamaindex.ai>

I can not list all the contributors here, but you can find them on the [llama_index GitHub page](https://github.com/run-llama/llama_index).
